@@ -12,8 +12,8 @@ fishkent <- function(x, B = 999) {
   ## B is by default eaual to 999 bootstrap re-samples
   ## If B==1 then no bootstrap is performed
   n <- dim(x)[1]  ## sample size
-  estim <- Directional::vmf.mle(x)
-  k <- estim$k  ## the estimated concentration parameter
+  estim <- Directional::vmf.mle(x, fast = TRUE)
+  k <- estim$kappa  ## the estimated concentration parameter
   ## under the H0, that the Fisher distribution is true
   mu <- estim$mu  ## the estimated mean direction under H0
   e1 <- c(1, 0, 0)
